<?php

namespace Drupal\bim_gdpr\Plugin\bim_gdpr\BimGdprServiceType;

use Drupal\bim_gdpr\BimGdprServiceInterface;
use Drupal\bim_gdpr\PluginManager\BimGdprServiceType\AbstractBimGdprServiceType;
use Drupal\bim_gdpr\PluginManager\BimGdprServiceType\BimGdprServiceTypeInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation For the type processor.
 *
 * @BimGdprServiceTypeAnnotation(
 *   id = "facebook_id",
 *   label = "Facebook Id",
 * )
 */
class FacebookIdBimGdprServiceType extends AbstractBimGdprServiceType implements BimGdprServiceTypeInterface {

  use StringTranslationTrait;

  /**
   * FacebookId constructor.
   */
  public function __construct() {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): BimGdprServiceTypeInterface {
    return new static();
  }

  /**
   * {@inheritdoc}
   */
  public function getConfigForm(BimGdprServiceInterface $service, array $parentForm, FormStateInterface $formState, array $requiredStates = []): array {
    $data = $service->getData();
    $form = [];
    $form['fb_pixel_id'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Facebook Pixel ID'),
      '#default_value' => isset($data['fb_pixel_id']) ? $data['fb_pixel_id'] : '',
      '#states'        => $requiredStates,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getMassagedConfigFormValue(array $values, array $form, FormStateInterface $formState): array {
    return $values;
  }

  /**
   * {@inheritdoc}
   */
  public function alterSettingsBeforeApply(array &$settings) {
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries(): array {
    return [
      'bim_gdpr/services.facebook_pixel',
    ];
  }

}
